@@ -1,4 +1,5 @@
 import os
+import warnings
 
 
 def restart_runtime():
@@ -22,24 +23,27 @@ def is_colab():
 
 
 def collab_installer():
+    warnings.warn("Currently not working on google collab! (maybe only with python 3.7?)")
     import os
-    sucess = os.system('''
-    apt install chromium-chromedriver >> tmp;
-    apt install -y xvfb >> tmp;
-    cp /usr/lib/chromium-browser/chromedriver /usr/bin >> tmp;
-    zip -j /content/chromedriver_linux64.zip /usr/bin/chromedriver >> tmp;
+    import undetected_chromedriver
+    success = os.system('''
+    apt install chromium-chromedriver >> mytmp;
+    apt install -y xvfb >> mytmp;
+    cp /usr/lib/chromium-browser/chromedriver /usr/bin >> mytmp;
+    zip -j /content/chromedriver_linux64.zip /usr/bin/chromedriver >> mytmp;
     ''')
-    with open('tmp', 'r') as f:
+    with open('mytmp', 'r') as f:
         out = f.read()
-    os.remove('tmp')
-    patcher_src = "/usr/local/lib/python3.7/dist-packages/undetected_chromedriver/patcher.py"
+    os.remove('mytmp')
+
+    patcher_src = os.path.dirname(undetected_chromedriver.__file__)+"/patcher.py"
     with open(patcher_src, "r") as f:
         contents = f.read()
         contents = contents.replace("return urlretrieve(u)[0]",
                                     "return urlretrieve('file:///content/chromedriver_linux64.zip',""filename='/tmp/chromedriver_linux64.zip')[0]")
     with open(patcher_src, "w") as f:
         f.write(contents)
-    if sucess == 0:
+    if success == 0:
         return out
     else:
         print(out)
